"""UI components for the dashboard."""

from .network_panel import NetworkPanel
from .news_panel import NewsPanel
from .status_bar import StatusBar

__all__ = ["NetworkPanel", "NewsPanel", "StatusBar"]
